# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from enum import Enum
from typing import Dict, List, Optional

from pydantic import BaseModel, Field


class State(Enum):
    disabled = "DISABLED"
    hidden = "HIDDEN"
    enabled = "ENABLED"
    archived = "ARCHIVED"


class Tracking(Enum):
    lifetime = "LIFETIME"
    season = "SEASON"


class ChallengeConfigInfoDto(BaseModel):
    id: int
    localized_names: Dict[str, Dict[str, str]] = Field(..., alias="localizedNames")
    state: State = Field(
        ...,
        description="DISABLED - not visible and not calculated, HIDDEN - not visible, but calculated, ENABLED - visible and calculated, ARCHIVED - visible, but not calculated",
    )
    tracking: Optional[Tracking] = Field(
        None,
        description="LIFETIME - stats are incremented without reset, SEASON - stats are accumulated by season and reset at the beginning of new season",
    )
    start_timestamp: Optional[int] = Field(None, alias="startTimestamp")
    end_timestamp: Optional[int] = Field(None, alias="endTimestamp")
    leaderboard: bool
    thresholds: Dict[str, float]


class StateModel(BaseModel):
    pass


class TrackingModel(BaseModel):
    pass


class ApexPlayerInfoDto(BaseModel):
    puuid: str
    value: float
    position: int


class Level(BaseModel):
    pass


class LevelModel(Enum):
    none = "NONE"
    iron = "IRON"
    bronze = "BRONZE"
    silver = "SILVER"
    gold = "GOLD"
    platinum = "PLATINUM"
    diamond = "DIAMOND"
    master = "MASTER"
    grandmaster = "GRANDMASTER"
    challenger = "CHALLENGER"
    highest_not_leaderboard_only = "HIGHEST_NOT_LEADERBOARD_ONLY"
    highest = "HIGHEST"
    lowest = "LOWEST"


class ChallengeInfoDto(BaseModel):
    percentile: float
    players_in_level: Optional[int] = Field(None, alias="playersInLevel")
    achieved_time: Optional[int] = Field(None, alias="achievedTime")
    value: float
    challenge_id: int = Field(..., alias="challengeId")
    level: LevelModel = Field(
        ...,
        description="(Legal values:  NONE,  IRON,  BRONZE,  SILVER,  GOLD,  PLATINUM,  DIAMOND,  MASTER,  GRANDMASTER,  CHALLENGER,  HIGHEST_NOT_LEADERBOARD_ONLY,  HIGHEST,  LOWEST)",
    )
    position: Optional[int] = None


class PlayerClientPreferencesDto(BaseModel):
    banner_accent: Optional[str] = Field(None, alias="bannerAccent")
    title: Optional[str] = None
    challenge_ids: Optional[List[int]] = Field(None, alias="challengeIds")
    crest_border: Optional[str] = Field(None, alias="crestBorder")
    prestige_crest_border_level: Optional[int] = Field(
        None, alias="prestigeCrestBorderLevel"
    )


class ChallengePointDto(BaseModel):
    level: str
    current: int
    max: int
    percentile: Optional[float] = None


class PlayerInfoDto(BaseModel):
    challenges: List[ChallengeInfoDto]
    preferences: PlayerClientPreferencesDto
    total_points: ChallengePointDto = Field(..., alias="totalPoints")
    category_points: Dict[str, ChallengePointDto] = Field(..., alias="categoryPoints")



class BadRequest(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class Unauthorized(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class Forbidden(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class DataNotFound(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class MethodNotAllowed(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class UnsupportedMediaType(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class RateLimitExceeded(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class InternalServerError(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class BadGateway(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class ServiceUnavailable(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class GatewayTimeout(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"


class UnknownError(Exception):
    def __init__(self, message: str, error_code: int):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

    def __str__(self):
        return f"{self.message} (Error Code: {self.error_code})"



from enum import Enum


class Level(Enum):
    """# Challenge level"""

    NONE = "NONE"
    IRON = "IRON"
    BRONZE = "BRONZE"
    SILVER = "SILVER"
    GOLD = "GOLD"
    PLATINUM = "PLATINUM"
    EMERALD = "EMERALD"
    DIAMOND = "DIAMOND"
    MASTER = "MASTER"
    GRANDMASTER = "GRANDMASTER"
    CHALLENGER = "CHALLENGER"
    HIGHEST_NOT_LEADERBOARD_ONLY = "HIGHEST_NOT_LEADERBOARD_ONLY"
    HIGHEST = "HIGHEST"
    LOWEST = "LOWEST"



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Field


class MiniSeriesDTO(BaseModel):
    losses: int
    progress: str
    target: int
    wins: int


class LeagueEntryDTO(BaseModel):
    league_id: str = Field(..., alias="leagueId")
    summoner_id: Optional[str] = Field(
        None, alias="summonerId", description="Player's summonerId (Encrypted)"
    )
    puuid: str = Field(..., description="Player's encrypted puuid.")
    queue_type: str = Field(..., alias="queueType")
    tier: str
    rank: str = Field(..., description="The player's division within a tier.")
    league_points: int = Field(..., alias="leaguePoints")
    wins: int = Field(
        ...,
        description="Winning team on Summoners Rift. First placement in Teamfight Tactics.",
    )
    losses: int = Field(
        ...,
        description="Losing team on Summoners Rift. Second through eighth placement in Teamfight Tactics.",
    )
    hot_streak: bool = Field(..., alias="hotStreak")
    veteran: bool
    fresh_blood: bool = Field(..., alias="freshBlood")
    inactive: bool
    mini_series: Optional[MiniSeriesDTO] = Field(None, alias="miniSeries")



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel


class Status(BaseModel):
    status_code: Optional[int] = None
    message: Optional[str] = None


class Error(BaseModel):
    status: Optional[Status] = None



from . import exceptions
from .__version__ import __author__, __title__, __version__
from ._enums.continent import Continent
from ._enums.division import Division
from ._enums.level import Level
from ._enums.queue import Queue
from ._enums.region import Region
from ._enums.tier import Tier
from ._enums.type import Type
from .main import Pyke

__all__ = [
    "exceptions",
    "Continent",
    "Division",
    "Level",
    "Queue",
    "Region",
    "Tier",
    "Type",
    "Pyke",
]



from pyke import Level, Region

from .._base_client import _BaseApiClient
from .._models.challenges_v1 import (
    ApexPlayerInfoDto,
    ChallengeConfigInfoDto,
    PlayerInfoDto,
)


class ChallengesEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def config(self, region: Region) -> list[ChallengeConfigInfoDto]:
        """# List of all basic challenge configuration information (includes all translations for names and descriptions)

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  

        **Returns:**  
            `list[ChallengeConfigInfoDto]:` List of pyke._models.challenges_v1.ChallengeConfigInfoDto objects.
        """  # fmt: skip

        path = "/lol/challenges/v1/challenges/config"
        data = self._client._region_request(region=region, path=path)

        challenge_configs: list[ChallengeConfigInfoDto] = []

        for challenge_config in data:
            challenge_configs.append(ChallengeConfigInfoDto(**challenge_config))

        return challenge_configs

    def percentiles(self, region: Region) -> dict[int, dict[int, dict[str, int]]]:
        """# Map of level to percentile of players who have achieved it - keys: ChallengeId -> Season -> Level -> percentile of players who achieved it

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  

        **Returns:**  
            `dict[int, dict[int, dict[str, int]]]:` Map of level to percentile of players who have achieved it - keys: ChallengeId -> Season -> Level -> percentile of players who achieved it.
        """  # fmt: skip

        path = "/lol/challenges/v1/challenges/percentiles"
        data = self._client._region_request(region=region, path=path)

        return data

    def config_by_challenge_id(
        self, region: Region, challenge_id: int
    ) -> ChallengeConfigInfoDto:
        """# Get challenge configuration (REST)

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `challenge_id (int):` Challenge id integer.  

        **Returns:**  
            `ChallengeConfigInfoDto:` pyke._models.challenges_v1.ChallengeConfigInfoDto object.
        """  # fmt: skip

        path = f"/lol/challenges/v1/challenges/{challenge_id}/config"
        data = self._client._region_request(region=region, path=path)

        return ChallengeConfigInfoDto(**data)

    def leaderboards_by_level(
        self, region: Region, level: Level, challenge_id: int
    ) -> list[ApexPlayerInfoDto]:
        """# Return top players for each level. Level must be MASTER, GRANDMASTER or CHALLENGER

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `level (Level):` Challenge level (pyke._enums.level.Level).  
            `challenge_id (int):` Challenge id integer.  

        **Returns:**  
            `list[ApexPlayerInfoDto]:` List of pyke._models.challenges_v1.ApexPlayerInfoDto objects.
        """  # fmt: skip

        path = f"/lol/challenges/v1/challenges/{challenge_id}/leaderboards/by-level/{level.value}"
        data = self._client._region_request(region=region, path=path)

        apex_player_infos: list[ApexPlayerInfoDto] = []

        for apex_player_info in data:
            apex_player_infos.append(ApexPlayerInfoDto(**apex_player_info))

        return apex_player_infos

    def percentiles_by_challenge_id(
        self, region: Region, challenge_id: int
    ) -> dict[Level, int]:
        """# Dictionary of level to percentile of players who have achieved it

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `challenge_id (int):` Challenge id integer.  

        **Returns:**  
            `dict[Level, int]:` Python dictionary {pyke._enums.level.Level: percentile of players who achieved the challenge}
        """  # fmt: skip

        path = f"/lol/challenges/v1/challenges/{challenge_id}/percentiles"
        data = self._client._region_request(region=region, path=path)

        return data

    def by_puuid(self, region: Region, puuid: str) -> PlayerInfoDto:
        """# Returns player information with list of all progressed challenges (REST)

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `PlayerInfoDto:` pyke._models.challenges_v1.PlayerInfoDto object.
        """  # fmt: skip

        path = f"/lol/challenges/v1/player-data/{puuid}"
        data = self._client._region_request(region=region, path=path)

        return PlayerInfoDto(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Dict, List, Optional

from pydantic import BaseModel, Field


class RewardConfigDto(BaseModel):
    reward_value: str = Field(..., alias="rewardValue", description="Reward value")
    reward_type: str = Field(..., alias="rewardType", description="Reward type")
    maximum_reward: int = Field(
        ..., alias="maximumReward", description="Maximun reward"
    )


class NextSeasonMilestonesDto(BaseModel):
    require_grade_counts: Dict[str, int] = Field(..., alias="requireGradeCounts")
    reward_marks: int = Field(..., alias="rewardMarks", description="Reward marks.")
    bonus: bool = Field(..., description="Bonus.")
    reward_config: Optional[RewardConfigDto] = Field(
        None, alias="rewardConfig", description="Reward configuration."
    )
    total_games_requires: int = Field(..., alias="totalGamesRequires")


class ChampionMasteryDto(BaseModel):
    puuid: str = Field(
        ...,
        description="Player Universal Unique Identifier. Exact length of 78 characters. (Encrypted)",
    )
    champion_points_until_next_level: int = Field(
        ...,
        alias="championPointsUntilNextLevel",
        description="Number of points needed to achieve next level. Zero if player reached maximum champion level for this champion.",
    )
    chest_granted: Optional[bool] = Field(
        None,
        alias="chestGranted",
        description="Is chest granted for this champion or not in current season.",
    )
    champion_id: int = Field(
        ..., alias="championId", description="Champion ID for this entry."
    )
    last_play_time: int = Field(
        ...,
        alias="lastPlayTime",
        description="Last time this champion was played by this player - in Unix milliseconds time format.",
    )
    champion_level: int = Field(
        ...,
        alias="championLevel",
        description="Champion level for specified player and champion combination.",
    )
    champion_points: int = Field(
        ...,
        alias="championPoints",
        description="Total number of champion points for this player and champion combination - they are used to determine championLevel.",
    )
    champion_points_since_last_level: int = Field(
        ...,
        alias="championPointsSinceLastLevel",
        description="Number of points earned since current level has been achieved.",
    )
    mark_required_for_next_level: int = Field(..., alias="markRequiredForNextLevel")
    champion_season_milestone: int = Field(..., alias="championSeasonMilestone")
    next_season_milestone: NextSeasonMilestonesDto = Field(
        ..., alias="nextSeasonMilestone"
    )
    tokens_earned: int = Field(
        ...,
        alias="tokensEarned",
        description="The token earned for this champion at the current championLevel. When the championLevel is advanced the tokensEarned resets to 0.",
    )
    milestone_grades: Optional[List[str]] = Field(None, alias="milestoneGrades")



from pyke import Continent

from .._base_client import _BaseApiClient
from .._models.account_v1 import AccountDto, AccountRegionDTO


class AccountEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def by_puuid(self, continent: Continent, puuid: str) -> AccountDto:
        """# Get account by puuid

        **Args:**  
            `continent (Continent):` Continent to execute against (pyke._enums.continent.Continent).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `AccountDto:` pyke._models.account_v1.AccountDto object.
        """  # fmt: skip

        path = f"/riot/account/v1/accounts/by-puuid/{puuid}"
        data = self._client._continent_request(continent=continent, path=path)

        return AccountDto(**data)

    def by_riot_id(
        self, continent: Continent, game_name: str, tag_line: str
    ) -> AccountDto:
        """# Get account by riot id

        **Args:**  
            `continent (Continent):` Continent to execute against (pyke._enums.continent.Continent).  
            `game_name (str):` Riot id game name.  
            `tag_line (str):` Riot id tag line.  

        **Returns:**  
            `AccountDto:` pyke._models.account_v1.AccountDto object.
        """  # fmt: skip

        path = f"/riot/account/v1/accounts/by-riot-id/{game_name}/{tag_line}"
        data = self._client._continent_request(continent=continent, path=path)

        return AccountDto(**data)

    def region_by_puuid(self, continent: Continent, puuid: str) -> AccountRegionDTO:
        """# Get active region (lol and tft)

        **Args:**  
            `continent (Continent):` Continent to execute against (pyke._enums.continent.Continent).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `AccountRegionDTO:` pyke._models.account_v1.AccountRegionDTO object.
        """  # fmt: skip

        path = f"/riot/account/v1/region/by-game/lol/by-puuid/{puuid}"
        data = self._client._continent_request(continent=continent, path=path)

        return AccountRegionDTO(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Field


class ChampionInfo(BaseModel):
    max_new_player_level: int = Field(..., alias="maxNewPlayerLevel")
    free_champion_ids_for_new_players: List[int] = Field(
        ..., alias="freeChampionIdsForNewPlayers"
    )
    free_champion_ids: List[int] = Field(..., alias="freeChampionIds")



import json

import requests

url = "http://www.mingweisamuel.com/riotapi-schema/openapi-3.0.0.json"

response = requests.get(url)

code = response.status_code

if code == 200:
    json_content = response.json()

    with open("./pyke/schema/schema.json", "w") as f:
        json.dump(json_content, f, indent=4)
else:
    print(f"Error: {code}")
    quit()



from enum import Enum


class Region(Enum):
    """# Region to execute against"""

    BR = "br1"
    EUNE = "eun1"
    EUW = "euw1"
    JP = "JP1"
    KR = "kr"
    LAN = "la1"
    LAS = "la2"
    ME = "me1"
    NA = "na1"
    OCE = "oc1"
    RU = "ru1"
    TR = "tr1"
    PH = "ph2"
    SG = "sg2"
    TH = "th2"
    TW = "tw2"
    VN = "vn2"



import time
from typing import Any

import requests

from . import exceptions
from ._enums.continent import Continent
from ._enums.region import Region


class _BaseApiClient:  # pyright: ignore[reportUnusedClass]
    CONTINENT_BASE = "https://{continent}.api.riotgames.com"
    REGION_BASE = "https://{region}.api.riotgames.com"

    def __init__(self, api_key: str | None, log_url: bool):
        self.api_key = api_key
        self.log_url = log_url

    def _get(self, url: str, params: dict[Any, Any] | None = None):
        while True:
            headers = {"X-Riot-Token": self.api_key}
            response = requests.get(url, headers=headers, params=params)

            if self.log_url:
                limit = response.headers.get("X-App-Rate-Limit", "unknown")
                count = response.headers.get("X-App-Rate-Limit-Count", "unknown")
                print(f"({count.split(':')[0]}/{limit.split(':')[0]}) - {url}")

            code = response.status_code

            if code == 200:
                try:
                    return response.json()
                except ValueError:
                    raise exceptions.InternalServerError("Empty JSON response", 500)

            elif code == 400:
                raise exceptions.BadRequest("Bad request", 400)
            elif code == 401:
                raise exceptions.Unauthorized("Unauthorized", 401)
            elif code == 403:
                raise exceptions.Forbidden("Forbidden", 403)
            elif code == 404:
                raise exceptions.DataNotFound("Data not found", 404)
            elif code == 405:
                raise exceptions.MethodNotAllowed("Method not allowed", 405)
            elif code == 415:
                raise exceptions.UnsupportedMediaType("Unsupported media type", 415)
            elif code == 429:
                retry_after = int(response.headers.get("Retry-After", "120"))
                print(f"Rate limit exceeded, waiting {retry_after} seconds")
                time.sleep(retry_after)
                continue
            elif code == 500:
                raise exceptions.InternalServerError("Internal server error", 500)
            elif code == 502:
                raise exceptions.BadGateway("Bad gateway", 502)
            elif code == 503:
                raise exceptions.ServiceUnavailable("Service unavailable", 503)
            elif code == 504:
                raise exceptions.GatewayTimeout("Gateway timeout", 504)
            else:
                raise exceptions.UnknownError(
                    "Unexpected response, something has gone terribly wrong", code
                )

    def _continent_request(
        self, continent: Continent, path: str, params: dict[Any, Any] | None = None
    ):
        url = f"{self.CONTINENT_BASE.format(continent=continent.value)}{path}"
        return self._get(url, params)

    def _region_request(
        self, region: Region, path: str, params: dict[Any, Any] | None = None
    ):
        url = f"{self.REGION_BASE.format(region=region.value)}{path}"
        return self._get(url, params)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Field


class AccountDto(BaseModel):
    puuid: str = Field(
        ..., description="Encrypted PUUID. Exact length of 78 characters."
    )
    game_name: Optional[str] = Field(
        None,
        alias="gameName",
        description="This field may be excluded from the response if the account doesn't have a gameName.",
    )
    tag_line: Optional[str] = Field(
        None,
        alias="tagLine",
        description="This field may be excluded from the response if the account doesn't have a tagLine.",
    )


class AccountRegionDTO(BaseModel):
    puuid: str = Field(
        ...,
        description="Player Universal Unique Identifier. Exact length of 78 characters. (Encrypted)",
    )
    game: str = Field(..., description="Game to lookup active region")
    region: str = Field(..., description="Player active region")


class ActiveShardDto(BaseModel):
    puuid: str
    game: str
    active_shard: str = Field(..., alias="activeShard")



from pyke import Region

from .._base_client import _BaseApiClient
from .._models.champion_v3 import ChampionInfo


class ChampionEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def rotations(self, region: Region) -> ChampionInfo:
        """# Returns champion rotations, including free-to-play and low-level free-to-play rotations

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  

        **Returns:**  
            `ChampionInfo:` pyke._models.champion_v3.ChampionInfo object.
        """  # fmt: skip

        path = "/lol/platform/v3/champion-rotations"
        data = self._client._region_request(region=region, path=path)

        return ChampionInfo(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Field, conint


class PickType(Enum):
    blind_pick = "BLIND_PICK"
    draft_mode = "DRAFT_MODE"
    all_random = "ALL_RANDOM"
    tournament_draft = "TOURNAMENT_DRAFT"


class MapType(Enum):
    summoners_rift = "SUMMONERS_RIFT"
    howling_abyss = "HOWLING_ABYSS"


class SpectatorType(Enum):
    none = "NONE"
    lobbyonly = "LOBBYONLY"
    all = "ALL"


class TournamentCodeParametersV5(BaseModel):
    allowed_participants: Optional[List[str]] = Field(
        None,
        alias="allowedParticipants",
        description="Optional list of encrypted puuids in order to validate the players eligible to join the lobby. NOTE: We currently do not enforce participants at the team level, but rather the aggregate of teamOne and teamTwo. We may add the ability to enforce at the team level in the future.",
    )
    metadata: Optional[str] = Field(
        None,
        description="Optional string that may contain any data in any format, if specified at all. Used to denote any custom information about the game.",
    )
    team_size: conint(ge=1, le=5) = Field(
        ...,
        alias="teamSize",
        description="The team size of the game. Valid values are 1-5.",
    )
    pick_type: PickType = Field(
        ...,
        alias="pickType",
        description="The pick type of the game.\n             (Legal values:  BLIND_PICK,  DRAFT_MODE,  ALL_RANDOM,  TOURNAMENT_DRAFT)",
    )
    map_type: MapType = Field(
        ...,
        alias="mapType",
        description="The map type of the game.\n             (Legal values:  SUMMONERS_RIFT,  HOWLING_ABYSS)",
    )
    spectator_type: SpectatorType = Field(
        ...,
        alias="spectatorType",
        description="The spectator type of the game.\n             (Legal values:  NONE,  LOBBYONLY,  ALL)",
    )
    enough_players: bool = Field(
        ...,
        alias="enoughPlayers",
        description="Checks if allowed participants are enough to make full teams.",
    )


class Region(Enum):
    br = "BR"
    eune = "EUNE"
    euw = "EUW"
    jp = "JP"
    lan = "LAN"
    las = "LAS"
    na = "NA"
    oce = "OCE"
    pbe = "PBE"
    ru = "RU"
    tr = "TR"
    kr = "KR"


class TournamentCodeV5DTO(BaseModel):
    code: str = Field(..., description="The tournament code.")
    lobby_name: str = Field(
        ...,
        alias="lobbyName",
        description="The lobby name for the tournament code game.",
    )
    meta_data: str = Field(
        ..., alias="metaData", description="The metadata for tournament code."
    )
    password: str = Field(..., description="The password for the tournament code game.")
    team_size: int = Field(
        ..., alias="teamSize", description="The team size for the tournament code game."
    )
    provider_id: int = Field(..., alias="providerId", description="The provider's ID.")
    pick_type: str = Field(
        ..., alias="pickType", description="The pick mode for tournament code game."
    )
    tournament_id: int = Field(
        ..., alias="tournamentId", description="The tournament's ID."
    )
    id: int = Field(..., description="The tournament code's ID.")
    region: Region = Field(
        ...,
        description="The tournament code's region.\n             (Legal values:  BR,  EUNE,  EUW,  JP,  LAN,  LAS,  NA,  OCE,  PBE,  RU,  TR,  KR)",
    )
    map: str = Field(..., description="The game map for the tournament code game")
    participants: List[str] = Field(
        ..., description="The puuids of the participants (Encrypted)"
    )


class LobbyEventV5DTO(BaseModel):
    timestamp: str = Field(..., description="Timestamp from the event")
    event_type: str = Field(
        ..., alias="eventType", description="The type of event that was triggered"
    )
    puuid: str = Field(
        ..., description="The puuid that triggered the event (Encrypted)"
    )


class ProviderRegistrationParametersV5(BaseModel):
    region: Region = Field(
        ...,
        description="The region in which the provider will be running tournaments.\n             (Legal values:  BR,  EUNE,  EUW,  JP,  LAN,  LAS,  NA,  OCE,  PBE,  RU,  TR,  KR)",
    )
    url: str = Field(
        ...,
        description="The provider's callback URL to which tournament game results in this region should be posted. The URL must be well-formed, use the http or https protocol, and use the default port for the protocol (http URLs must use port 80, https URLs must use port 443).",
    )


class TournamentRegistrationParametersV5(BaseModel):
    provider_id: int = Field(
        ...,
        alias="providerId",
        description="The provider ID to specify the regional registered provider data to associate this tournament.",
    )
    name: Optional[str] = Field(
        None, description="The optional name of the tournament."
    )


class LobbyEventV5DTOWrapper(BaseModel):
    event_list: List[LobbyEventV5DTO] = Field(..., alias="eventList")



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Field


class BannedChampion(BaseModel):
    pick_turn: int = Field(
        ...,
        alias="pickTurn",
        description="The turn during which the champion was banned",
    )
    champion_id: int = Field(
        ..., alias="championId", description="The ID of the banned champion"
    )
    team_id: int = Field(
        ..., alias="teamId", description="The ID of the team that banned the champion"
    )


class Observer(BaseModel):
    encryption_key: str = Field(
        ...,
        alias="encryptionKey",
        description="Key used to decrypt the spectator grid game data for playback",
    )


class Perks(BaseModel):
    perk_ids: List[int] = Field(
        ..., alias="perkIds", description="IDs of the perks/runes assigned."
    )
    perk_style: int = Field(..., alias="perkStyle", description="Primary runes path")
    perk_sub_style: int = Field(
        ..., alias="perkSubStyle", description="Secondary runes path"
    )


class GameCustomizationObject(BaseModel):
    category: str = Field(..., description="Category identifier for Game Customization")
    content: str = Field(..., description="Game Customization content")


class GameMode(Enum):
    classic = "CLASSIC"
    odin = "ODIN"
    aram = "ARAM"
    tutorial = "TUTORIAL"
    oneforall = "ONEFORALL"
    ascension = "ASCENSION"
    firstblood = "FIRSTBLOOD"
    kingporo = "KINGPORO"


class GameType(Enum):
    custom_game = "CUSTOM_GAME"
    matched_game = "MATCHED_GAME"
    tutorial_game = "TUTORIAL_GAME"


class Participant(BaseModel):
    bot: bool = Field(
        ..., description="Flag indicating whether or not this participant is a bot"
    )
    spell2_id: int = Field(
        ...,
        alias="spell2Id",
        description="The ID of the second summoner spell used by this participant",
    )
    profile_icon_id: int = Field(
        ...,
        alias="profileIconId",
        description="The ID of the profile icon used by this participant",
    )
    puuid: Optional[str] = Field(
        None, description="Encrypted puuid of this participant"
    )
    champion_id: int = Field(
        ...,
        alias="championId",
        description="The ID of the champion played by this participant",
    )
    team_id: int = Field(
        ...,
        alias="teamId",
        description="The team ID of this participant, indicating the participant's team",
    )
    spell1_id: int = Field(
        ...,
        alias="spell1Id",
        description="The ID of the first summoner spell used by this participant",
    )
    riot_id: Optional[str] = Field(None, alias="riotId")


class CurrentGameParticipant(BaseModel):
    champion_id: int = Field(
        ...,
        alias="championId",
        description="The ID of the champion played by this participant",
    )
    perks: Optional[Perks] = Field(None, description="Perks/Runes Reforged Information")
    profile_icon_id: int = Field(
        ...,
        alias="profileIconId",
        description="The ID of the profile icon used by this participant",
    )
    bot: bool = Field(
        ..., description="Flag indicating whether or not this participant is a bot"
    )
    team_id: int = Field(
        ...,
        alias="teamId",
        description="The team ID of this participant, indicating the participant's team",
    )
    puuid: Optional[str] = Field(
        None, description="The encrypted puuid of this participant"
    )
    spell1_id: int = Field(
        ...,
        alias="spell1Id",
        description="The ID of the first summoner spell used by this participant",
    )
    spell2_id: int = Field(
        ...,
        alias="spell2Id",
        description="The ID of the second summoner spell used by this participant",
    )
    game_customization_objects: List[GameCustomizationObject] = Field(
        ..., alias="gameCustomizationObjects", description="List of Game Customizations"
    )
    riot_id: Optional[str] = Field(None, alias="riotId")


class FeaturedGameInfo(BaseModel):
    game_mode: GameMode = Field(
        ...,
        alias="gameMode",
        description="The game mode\n             (Legal values:  CLASSIC,  ODIN,  ARAM,  TUTORIAL,  ONEFORALL,  ASCENSION,  FIRSTBLOOD,  KINGPORO)",
    )
    game_length: int = Field(
        ...,
        alias="gameLength",
        description="The amount of time in seconds that has passed since the game started",
    )
    map_id: int = Field(..., alias="mapId", description="The ID of the map")
    game_type: GameType = Field(
        ...,
        alias="gameType",
        description="The game type\n             (Legal values:  CUSTOM_GAME,  MATCHED_GAME,  TUTORIAL_GAME)",
    )
    banned_champions: List[BannedChampion] = Field(
        ..., alias="bannedChampions", description="Banned champion information"
    )
    game_id: int = Field(..., alias="gameId", description="The ID of the game")
    observers: Observer = Field(..., description="The observer information")
    game_queue_config_id: int = Field(
        ...,
        alias="gameQueueConfigId",
        description="The queue type (queue types are documented on the Game Constants page)",
    )
    participants: List[Participant] = Field(
        ..., description="The participant information"
    )
    platform_id: str = Field(
        ...,
        alias="platformId",
        description="The ID of the platform on which the game is being played",
    )


class CurrentGameInfo(BaseModel):
    game_id: int = Field(..., alias="gameId", description="The ID of the game")
    game_type: str = Field(..., alias="gameType", description="The game type")
    game_start_time: int = Field(
        ...,
        alias="gameStartTime",
        description="The game start time represented in epoch milliseconds",
    )
    map_id: int = Field(..., alias="mapId", description="The ID of the map")
    game_length: int = Field(
        ...,
        alias="gameLength",
        description="The amount of time in seconds that has passed since the game started",
    )
    platform_id: str = Field(
        ...,
        alias="platformId",
        description="The ID of the platform on which the game is being played",
    )
    game_mode: str = Field(..., alias="gameMode", description="The game mode")
    banned_champions: List[BannedChampion] = Field(
        ..., alias="bannedChampions", description="Banned champion information"
    )
    game_queue_config_id: Optional[int] = Field(
        None,
        alias="gameQueueConfigId",
        description="The queue type (queue types are documented on the Game Constants page)",
    )
    observers: Observer = Field(..., description="The observer information")
    participants: List[CurrentGameParticipant] = Field(
        ..., description="The participant information"
    )


class FeaturedGames(BaseModel):
    game_list: List[FeaturedGameInfo] = Field(
        ..., alias="gameList", description="The list of featured games"
    )
    client_refresh_interval: Optional[int] = Field(
        None,
        alias="clientRefreshInterval",
        description="The suggested interval to wait before requesting FeaturedGames again",
    )



# pyke

from ._base_client import _BaseApiClient
from .endpoints.account import AccountEndpoint
from .endpoints.challenges import ChallengesEndpoint
from .endpoints.champion import ChampionEndpoint
from .endpoints.champion_mastery import ChampionMasteryEndpoint
from .endpoints.clash import ClashEndpoint
from .endpoints.league import LeagueEndpoint
from .endpoints.league_exp import LeagueExpEndpoint
from .endpoints.match import MatchEndpoint
from .endpoints.spectator import SpectatorEndpoint
from .endpoints.status import StatusEndpoint
from .endpoints.summoner import SummonerEndpoint
from .endpoints.tournament import TournamentEndpoint
from .endpoints.tournament_stub import TournamentStubEndpoint


class Pyke:
    """Main entrypoint for interacting with the Riot API."""

    def __init__(self, api_key: str | None = None, log_url: bool = True):
        self._client = _BaseApiClient(api_key, log_url)

        self.account = AccountEndpoint(self._client)
        self.champion_mastery = ChampionMasteryEndpoint(self._client)
        self.champion = ChampionEndpoint(self._client)
        self.clash = ClashEndpoint(self._client)
        self.league_exp = LeagueExpEndpoint(self._client)
        self.league = LeagueEndpoint(self._client)
        self.challenges = ChallengesEndpoint(self._client)
        self.status = StatusEndpoint(self._client)
        self.match = MatchEndpoint(self._client)
        self.spectator = SpectatorEndpoint(self._client)
        self.summoner = SummonerEndpoint(self._client)
        self.tournament_stub = TournamentStubEndpoint(self._client)
        self.tournament = TournamentEndpoint(self._client)



from pyke import Region

from .._base_client import _BaseApiClient
from .._models.champion_mastery_v4 import ChampionMasteryDto


class ChampionMasteryEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def masteries_by_puuid(
        self, region: Region, puuid: str
    ) -> list[ChampionMasteryDto]:
        """# Get all champion mastery entries sorted by number of champion points descending

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `list[ChampionMasteryDto]:` List of pyke._models.champion_mastery_v4.ChampionMasteryDto objects.
        """  # fmt: skip

        path = f"/lol/champion-mastery/v4/champion-masteries/by-puuid/{puuid}"
        data = self._client._region_request(region=region, path=path)

        champion_masteries: list[ChampionMasteryDto] = []

        for champion_mastery in data:
            champion_masteries.append(ChampionMasteryDto(**champion_mastery))

        return champion_masteries

    def by_puuid_and_champion_id(
        self, region: Region, puuid: str, champion_id: int
    ) -> ChampionMasteryDto:
        """# Get a champion mastery by puuid and champion ID

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  
            `champion_id (int):` Champion ID for this entry.  

        **Returns:**  
            `ChampionMasteryDto:` pyke._models.champion_mastery_v4.ChampionMasteryDto object.
        """  # fmt: skip

        path = f"/lol/champion-mastery/v4/champion-masteries/by-puuid/{puuid}/by-champion/{champion_id}"
        data = self._client._region_request(region=region, path=path)

        return ChampionMasteryDto(**data)

    def masteries_by_puuid_top(
        self, region: Region, puuid: str, count: int | None = None
    ) -> list[ChampionMasteryDto]:
        """# Get specified number of top champion mastery entries sorted by number of champion points descending

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  
            `count (int | None, optional):` Number of entries to retrieve. defaults to 3.  

        **Returns:**  
            `list[ChampionMasteryDTO]:` List of pyke._models.champion_mastery_v4.ChampionMasteryDTO objects.
        """  # fmt: skip

        path = f"/lol/champion-mastery/v4/champion-masteries/by-puuid/{puuid}/top"
        params = {"count": count}
        data = self._client._region_request(region=region, path=path, params=params)

        champion_masteries: list[ChampionMasteryDto] = []

        for champion_mastery in data:
            champion_masteries.append(ChampionMasteryDto(**champion_mastery))

        return champion_masteries

    def score_by_puuid(self, region: Region, puuid: str) -> int:
        """# Get a player's total champion mastery score, which is the sum of individual champion mastery levels

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `int:` Player's total champion mastery score.
        """  # fmt: skip

        path = f"/lol/champion-mastery/v4/scores/by-puuid/{puuid}"
        data = self._client._region_request(region=region, path=path)

        return data



from pyke import Region

from .._base_client import _BaseApiClient
from .._models.summoner_v4 import SummonerDTO


class SummonerEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def by_puuid(self, region: Region, puuid: str) -> SummonerDTO:
        """Get a summoner by PUUID.

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `CurrentGameInfo:` pyke._models.summoner_v4.SummonerDTO
        """  # fmt: skip

        path = f"/lol/summoner/v4/summoners/by-puuid/{puuid}"
        data = self._client._region_request(region=region, path=path)

        return SummonerDTO(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Field


class MaintenanceStatus(Enum):
    scheduled = "scheduled"
    in_progress = "in_progress"
    complete = "complete"


class IncidentSeverity(Enum):
    info = "info"
    warning = "warning"
    critical = "critical"


class Platform(Enum):
    windows = "windows"
    macos = "macos"
    android = "android"
    ios = "ios"
    ps4 = "ps4"
    xbone = "xbone"
    switch = "switch"


class ContentDto(BaseModel):
    locale: str
    content: str


class PublishLocation(Enum):
    riotclient = "riotclient"
    riotstatus = "riotstatus"
    game = "game"


class UpdateDto(BaseModel):
    id: int
    author: str
    publish: bool
    publish_locations: List[PublishLocation] = Field(
        ..., description="(Legal values: riotclient, riotstatus, game)"
    )
    translations: List[ContentDto]
    created_at: str
    updated_at: str


class StatusDto(BaseModel):
    id: int
    maintenance_status: Optional[MaintenanceStatus] = Field(
        None, description="(Legal values:  scheduled,  in_progress,  complete)"
    )
    incident_severity: Optional[IncidentSeverity] = Field(
        None, description="(Legal values:  info,  warning,  critical)"
    )
    titles: List[ContentDto]
    updates: List[UpdateDto]
    created_at: str
    archive_at: Optional[str] = None
    updated_at: Optional[str] = None
    platforms: List[Platform] = Field(
        ...,
        description="(Legal values: windows, macos, android, ios, ps4, xbone, switch)",
    )


class PlatformDataDto(BaseModel):
    id: str
    name: str
    locales: List[str]
    maintenances: List[StatusDto]
    incidents: List[StatusDto]



from enum import Enum


class Tier(Enum):
    """# Ranked tier"""

    IRON = "IRON"
    BRONZE = "BRONZE"
    SILVER = "SILVER"
    GOLD = "GOLD"
    PLATINUM = "PLATINUM"
    EMERALD = "EMERALD"
    DIAMOND = "DIAMOND"
    MASTER = "MASTER"
    GRANDMASTER = "GRANDMASTER"
    CHALLENGER = "CHALLENGER"



from pyke import Region

from .._base_client import _BaseApiClient
from .._models.spectator_v5 import CurrentGameInfo


class SpectatorEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def by_puuid(self, region: Region, puuid: str) -> CurrentGameInfo:
        """# Get current game information for the given puuid

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `CurrentGameInfo:` pyke._models.spectator_v5.CurrentGameInfo
        """  # fmt: skip

        path = f"/lol/spectator/v5/active-games/by-summoner/{puuid}"
        data = self._client._region_request(region=region, path=path)

        return CurrentGameInfo(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Field


class SummonerDTO(BaseModel):
    profile_icon_id: int = Field(
        ...,
        alias="profileIconId",
        description="ID of the summoner icon associated with the summoner.",
    )
    revision_date: int = Field(
        ...,
        alias="revisionDate",
        description="Date summoner was last modified specified as epoch milliseconds. The following events will update this timestamp: profile icon change, playing the tutorial or advanced tutorial, finishing a game, summoner name change.",
    )
    puuid: str = Field(
        ..., description="Encrypted PUUID. Exact length of 78 characters."
    )
    summoner_level: int = Field(
        ...,
        alias="summonerLevel",
        description="Summoner level associated with the summoner.",
    )
    id: Optional[str] = Field(
        None,
        description="Encrypted summoner ID. This field is deprecated and will be removed. Use `puuid` instead.",
    )



from pyke import Continent, Type

from .._base_client import _BaseApiClient
from .._models.match_v5 import MatchDto, TimelineDto


class MatchEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def match_ids_by_puuid(
        self,
        continent: Continent,
        puuid: str,
        start_time: int | None = None,
        end_time: int | None = None,
        queue: int | None = None,
        type: Type | None = None,
        start: int | None = None,
        count: int | None = None,
    ) -> list[str]:
        """# Get a list of match ids by puuid

        **Args:**  
            `continent (Continent):` Continent to execute against (pyke._enums.continent.Continent).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  
            `start_time (int | None, optional):` Epoch timestamp in seconds. The matchlist started storing timestamps on June 16th, 2021. Any matches played before June 16th, 2021 won't be included in the results if the startTime filter is set. Defaults to None.  
            `end_time (int | None, optional):` Epoch timestamp in seconds. Defaults to None.  
            `queue (int | None, optional):` Filter the list of match ids by a specific queue id. This filter is mutually inclusive of the type filter meaning any match ids returned must match both the queue and type filters. Defaults to None.  
            `type (Type | None, optional):` Filter the list of match ids by the type of match. This filter is mutually inclusive of the queue filter meaning any match ids returned must match both the queue and type filters (pyke._enums.type.Type). Defaults to None.  
            `start (int | None, optional):` Start index. Defaults to 0.  
            `count (int | None, optional):` Valid values: 0 to 100. Number of match ids to return. Defaults to 20.  

        **Returns:**  
            `list[str]:` List of match id strings.
        """  # fmt: skip

        path = f"/lol/match/v5/matches/by-puuid/{puuid}/ids"
        params = {
            "startTime": start_time,
            "endTime": end_time,
            "queue": queue,
            "type": type,
            "start": start,
            "count": count,
        }
        data = self._client._continent_request(
            continent=continent, path=path, params=params
        )

        return data

    def by_match_id(self, continent: Continent, match_id: str) -> MatchDto:
        """# Get a match by match id

        **Args:**  
            `continent (Continent):` Continent to execute against (pyke._enums.continent.Continent).  
            `match_id (str):` Match id string.  

        **Returns:**  
            `MatchDto:` pyke._models.match_v5.MatchDto object.
        """  # fmt: skip

        path = f"/lol/match/v5/matches/{match_id}"
        data = self._client._continent_request(continent=continent, path=path)

        return MatchDto(**data)

    def timeline_by_match_id(self, continent: Continent, match_id: str) -> TimelineDto:
        """# Get a match timeline by match id

        **Args:**  
            `continent (Continent):` Continent to execute against (pyke._enums.continent.Continent).  
            `match_id (str):` Match id string.  

        **Returns:**  
            `TimelineDto:` pyke._models.match_v5.TimelineDto object.
        """  # fmt: skip

        path = f"/lol/match/v5/matches/{match_id}/timeline"
        data = self._client._continent_request(continent=continent, path=path)

        return TimelineDto(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from enum import Enum
from typing import Dict, List, Optional

from pydantic import BaseModel, Field


class MetadataDto(BaseModel):
    data_version: str = Field(
        ..., alias="dataVersion", description="Match data version."
    )
    match_id: str = Field(..., alias="matchId", description="Match id.")
    participants: List[str] = Field(..., description="A list of participant PUUIDs.")


class FasterSupportQuestCompletion(Enum):
    integer_0 = 0
    integer_1 = 1


class HadAfkTeammate(Enum):
    integer_0 = 0
    integer_1 = 1


class HighestCrowdControlScore(Enum):
    integer_0 = 0
    integer_1 = 1


class HighestWardKills(Enum):
    integer_0 = 0
    integer_1 = 1


class LaningPhaseGoldExpAdvantage(Enum):
    integer_0 = 0
    integer_1 = 1


class PlayedChampSelectPosition(Enum):
    integer_0 = 0
    integer_1 = 1


class ChallengesDto(BaseModel):
    field_12_assist_streak_count: Optional[int] = Field(
        None, alias="12AssistStreakCount"
    )
    baron_buff_gold_advantage_over_threshold: Optional[int] = Field(
        None, alias="baronBuffGoldAdvantageOverThreshold"
    )
    control_ward_time_coverage_in_river_or_enemy_half: Optional[float] = Field(
        None, alias="controlWardTimeCoverageInRiverOrEnemyHalf"
    )
    earliest_baron: Optional[float] = Field(None, alias="earliestBaron")
    earliest_dragon_takedown: Optional[float] = Field(
        None, alias="earliestDragonTakedown"
    )
    earliest_elder_dragon: Optional[float] = Field(None, alias="earliestElderDragon")
    early_laning_phase_gold_exp_advantage: Optional[float] = Field(
        None, alias="earlyLaningPhaseGoldExpAdvantage"
    )
    faster_support_quest_completion: Optional[FasterSupportQuestCompletion] = Field(
        None, alias="fasterSupportQuestCompletion"
    )
    fastest_legendary: Optional[float] = Field(None, alias="fastestLegendary")
    had_afk_teammate: Optional[HadAfkTeammate] = Field(None, alias="hadAfkTeammate")
    highest_champion_damage: Optional[int] = Field(None, alias="highestChampionDamage")
    highest_crowd_control_score: Optional[HighestCrowdControlScore] = Field(
        None, alias="highestCrowdControlScore"
    )
    highest_ward_kills: Optional[HighestWardKills] = Field(
        None, alias="highestWardKills"
    )
    jungler_kills_early_jungle: Optional[int] = Field(
        None, alias="junglerKillsEarlyJungle"
    )
    kills_on_laners_early_jungle_as_jungler: Optional[int] = Field(
        None, alias="killsOnLanersEarlyJungleAsJungler"
    )
    laning_phase_gold_exp_advantage: Optional[LaningPhaseGoldExpAdvantage] = Field(
        None, alias="laningPhaseGoldExpAdvantage"
    )
    legendary_count: Optional[int] = Field(None, alias="legendaryCount")
    max_cs_advantage_on_lane_opponent: Optional[float] = Field(
        None, alias="maxCsAdvantageOnLaneOpponent"
    )
    max_level_lead_lane_opponent: Optional[int] = Field(
        None, alias="maxLevelLeadLaneOpponent"
    )
    most_wards_destroyed_one_sweeper: Optional[int] = Field(
        None, alias="mostWardsDestroyedOneSweeper"
    )
    mythic_item_used: Optional[int] = Field(None, alias="mythicItemUsed")
    played_champ_select_position: Optional[PlayedChampSelectPosition] = Field(
        None, alias="playedChampSelectPosition"
    )
    solo_turrets_lategame: Optional[int] = Field(None, alias="soloTurretsLategame")
    takedowns_first25_minutes: Optional[int] = Field(
        None, alias="takedownsFirst25Minutes"
    )
    teleport_takedowns: Optional[int] = Field(None, alias="teleportTakedowns")
    third_inhibitor_destroyed_time: Optional[float] = Field(
        None, alias="thirdInhibitorDestroyedTime"
    )
    three_wards_one_sweeper_count: Optional[int] = Field(
        None, alias="threeWardsOneSweeperCount"
    )
    vision_score_advantage_lane_opponent: Optional[float] = Field(
        None, alias="visionScoreAdvantageLaneOpponent"
    )
    infernal_scale_pickup: Optional[int] = Field(None, alias="InfernalScalePickup")
    fist_bump_participation: Optional[int] = Field(None, alias="fistBumpParticipation")
    void_monster_kill: Optional[int] = Field(None, alias="voidMonsterKill")
    ability_uses: Optional[int] = Field(None, alias="abilityUses")
    aces_before15_minutes: Optional[int] = Field(None, alias="acesBefore15Minutes")
    allied_jungle_monster_kills: Optional[float] = Field(
        None, alias="alliedJungleMonsterKills"
    )
    baron_takedowns: Optional[int] = Field(None, alias="baronTakedowns")
    blast_cone_opposite_opponent_count: Optional[int] = Field(
        None, alias="blastConeOppositeOpponentCount"
    )
    bounty_gold: Optional[float] = Field(None, alias="bountyGold")
    buffs_stolen: Optional[int] = Field(None, alias="buffsStolen")
    complete_support_quest_in_time: Optional[int] = Field(
        None, alias="completeSupportQuestInTime"
    )
    control_wards_placed: Optional[int] = Field(None, alias="controlWardsPlaced")
    damage_per_minute: Optional[float] = Field(None, alias="damagePerMinute")
    damage_taken_on_team_percentage: Optional[float] = Field(
        None, alias="damageTakenOnTeamPercentage"
    )
    danced_with_rift_herald: Optional[int] = Field(None, alias="dancedWithRiftHerald")
    deaths_by_enemy_champs: Optional[int] = Field(None, alias="deathsByEnemyChamps")
    dodge_skill_shots_small_window: Optional[int] = Field(
        None, alias="dodgeSkillShotsSmallWindow"
    )
    double_aces: Optional[int] = Field(None, alias="doubleAces")
    dragon_takedowns: Optional[int] = Field(None, alias="dragonTakedowns")
    legendary_item_used: Optional[List[int]] = Field(None, alias="legendaryItemUsed")
    effective_heal_and_shielding: Optional[float] = Field(
        None, alias="effectiveHealAndShielding"
    )
    elder_dragon_kills_with_opposing_soul: Optional[int] = Field(
        None, alias="elderDragonKillsWithOpposingSoul"
    )
    elder_dragon_multikills: Optional[int] = Field(None, alias="elderDragonMultikills")
    enemy_champion_immobilizations: Optional[int] = Field(
        None, alias="enemyChampionImmobilizations"
    )
    enemy_jungle_monster_kills: Optional[float] = Field(
        None, alias="enemyJungleMonsterKills"
    )
    epic_monster_kills_near_enemy_jungler: Optional[int] = Field(
        None, alias="epicMonsterKillsNearEnemyJungler"
    )
    epic_monster_kills_within30_seconds_of_spawn: Optional[int] = Field(
        None, alias="epicMonsterKillsWithin30SecondsOfSpawn"
    )
    epic_monster_steals: Optional[int] = Field(None, alias="epicMonsterSteals")
    epic_monster_stolen_without_smite: Optional[int] = Field(
        None, alias="epicMonsterStolenWithoutSmite"
    )
    first_turret_killed: Optional[float] = Field(None, alias="firstTurretKilled")
    first_turret_killed_time: Optional[float] = Field(
        None, alias="firstTurretKilledTime"
    )
    flawless_aces: Optional[int] = Field(None, alias="flawlessAces")
    full_team_takedown: Optional[int] = Field(None, alias="fullTeamTakedown")
    game_length: Optional[float] = Field(None, alias="gameLength")
    get_takedowns_in_all_lanes_early_jungle_as_laner: Optional[int] = Field(
        None, alias="getTakedownsInAllLanesEarlyJungleAsLaner"
    )
    gold_per_minute: Optional[float] = Field(None, alias="goldPerMinute")
    had_open_nexus: Optional[int] = Field(None, alias="hadOpenNexus")
    immobilize_and_kill_with_ally: Optional[int] = Field(
        None, alias="immobilizeAndKillWithAlly"
    )
    initial_buff_count: Optional[int] = Field(None, alias="initialBuffCount")
    initial_crab_count: Optional[int] = Field(None, alias="initialCrabCount")
    jungle_cs_before10_minutes: Optional[float] = Field(
        None, alias="jungleCsBefore10Minutes"
    )
    jungler_takedowns_near_damaged_epic_monster: Optional[int] = Field(
        None, alias="junglerTakedownsNearDamagedEpicMonster"
    )
    kda: Optional[float] = None
    kill_after_hidden_with_ally: Optional[int] = Field(
        None, alias="killAfterHiddenWithAlly"
    )
    killed_champ_took_full_team_damage_survived: Optional[int] = Field(
        None, alias="killedChampTookFullTeamDamageSurvived"
    )
    killing_sprees: Optional[int] = Field(None, alias="killingSprees")
    kill_participation: Optional[float] = Field(None, alias="killParticipation")
    kills_near_enemy_turret: Optional[int] = Field(None, alias="killsNearEnemyTurret")
    kills_on_other_lanes_early_jungle_as_laner: Optional[int] = Field(
        None, alias="killsOnOtherLanesEarlyJungleAsLaner"
    )
    kills_on_recently_healed_by_aram_pack: Optional[int] = Field(
        None, alias="killsOnRecentlyHealedByAramPack"
    )
    kills_under_own_turret: Optional[int] = Field(None, alias="killsUnderOwnTurret")
    kills_with_help_from_epic_monster: Optional[int] = Field(
        None, alias="killsWithHelpFromEpicMonster"
    )
    knock_enemy_into_team_and_kill: Optional[int] = Field(
        None, alias="knockEnemyIntoTeamAndKill"
    )
    k_turrets_destroyed_before_plates_fall: Optional[int] = Field(
        None, alias="kTurretsDestroyedBeforePlatesFall"
    )
    land_skill_shots_early_game: Optional[int] = Field(
        None, alias="landSkillShotsEarlyGame"
    )
    lane_minions_first10_minutes: Optional[int] = Field(
        None, alias="laneMinionsFirst10Minutes"
    )
    lost_an_inhibitor: Optional[int] = Field(None, alias="lostAnInhibitor")
    max_kill_deficit: Optional[int] = Field(None, alias="maxKillDeficit")
    mejais_full_stack_in_time: Optional[int] = Field(
        None, alias="mejaisFullStackInTime"
    )
    more_enemy_jungle_than_opponent: Optional[float] = Field(
        None, alias="moreEnemyJungleThanOpponent"
    )
    multi_kill_one_spell: Optional[int] = Field(
        None,
        alias="multiKillOneSpell",
        description="This is an offshoot of the OneStone challenge. The code checks if a spell with the same instance ID does the final point of damage to at least 2 Champions. It doesn't matter if they're enemies, but you cannot hurt your friends.",
    )
    multikills: Optional[int] = None
    multikills_after_aggressive_flash: Optional[int] = Field(
        None, alias="multikillsAfterAggressiveFlash"
    )
    multi_turret_rift_herald_count: Optional[int] = Field(
        None, alias="multiTurretRiftHeraldCount"
    )
    outer_turret_executes_before10_minutes: Optional[int] = Field(
        None, alias="outerTurretExecutesBefore10Minutes"
    )
    outnumbered_kills: Optional[int] = Field(None, alias="outnumberedKills")
    outnumbered_nexus_kill: Optional[int] = Field(None, alias="outnumberedNexusKill")
    perfect_dragon_souls_taken: Optional[int] = Field(
        None, alias="perfectDragonSoulsTaken"
    )
    perfect_game: Optional[int] = Field(None, alias="perfectGame")
    pick_kill_with_ally: Optional[int] = Field(None, alias="pickKillWithAlly")
    poro_explosions: Optional[int] = Field(None, alias="poroExplosions")
    quick_cleanse: Optional[int] = Field(None, alias="quickCleanse")
    quick_first_turret: Optional[int] = Field(None, alias="quickFirstTurret")
    quick_solo_kills: Optional[int] = Field(None, alias="quickSoloKills")
    rift_herald_takedowns: Optional[int] = Field(None, alias="riftHeraldTakedowns")
    save_ally_from_death: Optional[int] = Field(None, alias="saveAllyFromDeath")
    scuttle_crab_kills: Optional[int] = Field(None, alias="scuttleCrabKills")
    shortest_time_to_ace_from_first_takedown: Optional[float] = Field(
        None, alias="shortestTimeToAceFromFirstTakedown"
    )
    skillshots_dodged: Optional[int] = Field(None, alias="skillshotsDodged")
    skillshots_hit: Optional[int] = Field(None, alias="skillshotsHit")
    snowballs_hit: Optional[int] = Field(None, alias="snowballsHit")
    solo_baron_kills: Optional[int] = Field(None, alias="soloBaronKills")
    swarm_defeat_aatrox: Optional[int] = Field(None, alias="SWARM_DefeatAatrox")
    swarm_defeat_briar: Optional[int] = Field(None, alias="SWARM_DefeatBriar")
    swarm_defeat_mini_bosses: Optional[int] = Field(
        None, alias="SWARM_DefeatMiniBosses"
    )
    swarm_evolve_weapon: Optional[int] = Field(None, alias="SWARM_EvolveWeapon")
    swarm_have3_passives: Optional[int] = Field(None, alias="SWARM_Have3Passives")
    swarm_kill_enemy: Optional[int] = Field(None, alias="SWARM_KillEnemy")
    swarm_pickup_gold: Optional[float] = Field(None, alias="SWARM_PickupGold")
    swarm_reach_level50: Optional[int] = Field(None, alias="SWARM_ReachLevel50")
    swarm_survive15_min: Optional[int] = Field(None, alias="SWARM_Survive15Min")
    swarm_win_with5_evolved_weapons: Optional[int] = Field(
        None, alias="SWARM_WinWith5EvolvedWeapons"
    )
    solo_kills: Optional[int] = Field(None, alias="soloKills")
    stealth_wards_placed: Optional[int] = Field(None, alias="stealthWardsPlaced")
    survived_single_digit_hp_count: Optional[int] = Field(
        None, alias="survivedSingleDigitHpCount"
    )
    survived_three_immobilizes_in_fight: Optional[int] = Field(
        None, alias="survivedThreeImmobilizesInFight"
    )
    takedown_on_first_turret: Optional[int] = Field(None, alias="takedownOnFirstTurret")
    takedowns: Optional[int] = None
    takedowns_after_gaining_level_advantage: Optional[int] = Field(
        None, alias="takedownsAfterGainingLevelAdvantage"
    )
    takedowns_before_jungle_minion_spawn: Optional[int] = Field(
        None, alias="takedownsBeforeJungleMinionSpawn"
    )
    takedowns_first_x_minutes: Optional[int] = Field(
        None, alias="takedownsFirstXMinutes"
    )
    takedowns_in_alcove: Optional[int] = Field(None, alias="takedownsInAlcove")
    takedowns_in_enemy_fountain: Optional[int] = Field(
        None, alias="takedownsInEnemyFountain"
    )
    team_baron_kills: Optional[int] = Field(None, alias="teamBaronKills")
    team_damage_percentage: Optional[float] = Field(None, alias="teamDamagePercentage")
    team_elder_dragon_kills: Optional[int] = Field(None, alias="teamElderDragonKills")
    team_rift_herald_kills: Optional[int] = Field(None, alias="teamRiftHeraldKills")
    took_large_damage_survived: Optional[int] = Field(
        None, alias="tookLargeDamageSurvived"
    )
    turret_plates_taken: Optional[int] = Field(None, alias="turretPlatesTaken")
    turrets_taken_with_rift_herald: Optional[int] = Field(
        None,
        alias="turretsTakenWithRiftHerald",
        description="Any player who damages a tower that is destroyed within 30 seconds of a Rift Herald charge will receive credit. A player who does not damage the tower will not receive credit.",
    )
    turret_takedowns: Optional[int] = Field(None, alias="turretTakedowns")
    twenty_minions_in3_seconds_count: Optional[int] = Field(
        None, alias="twentyMinionsIn3SecondsCount"
    )
    two_wards_one_sweeper_count: Optional[int] = Field(
        None, alias="twoWardsOneSweeperCount"
    )
    unseen_recalls: Optional[int] = Field(None, alias="unseenRecalls")
    vision_score_per_minute: Optional[float] = Field(None, alias="visionScorePerMinute")
    wards_guarded: Optional[int] = Field(None, alias="wardsGuarded")
    ward_takedowns: Optional[int] = Field(None, alias="wardTakedowns")
    ward_takedowns_before20_m: Optional[int] = Field(
        None, alias="wardTakedownsBefore20M"
    )
    heal_from_map_sources: Optional[float] = Field(None, alias="HealFromMapSources")


class MissionsDto(BaseModel):
    player_score0: Optional[float] = Field(None, alias="playerScore0")
    player_score1: Optional[float] = Field(None, alias="playerScore1")
    player_score2: Optional[float] = Field(None, alias="playerScore2")
    player_score3: Optional[float] = Field(None, alias="playerScore3")
    player_score4: Optional[float] = Field(None, alias="playerScore4")
    player_score5: Optional[float] = Field(None, alias="playerScore5")
    player_score6: Optional[float] = Field(None, alias="playerScore6")
    player_score7: Optional[float] = Field(None, alias="playerScore7")
    player_score8: Optional[float] = Field(None, alias="playerScore8")
    player_score9: Optional[float] = Field(None, alias="playerScore9")
    player_score10: Optional[float] = Field(None, alias="playerScore10")
    player_score11: Optional[float] = Field(None, alias="playerScore11")


class PerkStatsDto(BaseModel):
    defense: int
    flex: int
    offense: int


class PerkStyleSelectionDto(BaseModel):
    perk: int
    var1: int
    var2: int
    var3: int


class BanDto(BaseModel):
    champion_id: int = Field(..., alias="championId")
    pick_turn: int = Field(..., alias="pickTurn")


class ObjectiveDto(BaseModel):
    first: bool
    kills: int


class MetadataTimeLineDto(BaseModel):
    data_version: str = Field(
        ..., alias="dataVersion", description="Match data version."
    )
    match_id: str = Field(..., alias="matchId", description="Match id.")
    participants: List[str] = Field(..., description="A list of participant PUUIDs.")


class ParticipantTimeLineDto(BaseModel):
    participant_id: int = Field(..., alias="participantId")
    puuid: str


class ChampionStatsDto(BaseModel):
    ability_haste: Optional[int] = Field(None, alias="abilityHaste")
    ability_power: int = Field(..., alias="abilityPower")
    armor: int
    armor_pen: int = Field(..., alias="armorPen")
    armor_pen_percent: int = Field(..., alias="armorPenPercent")
    attack_damage: int = Field(..., alias="attackDamage")
    attack_speed: int = Field(..., alias="attackSpeed")
    bonus_armor_pen_percent: int = Field(..., alias="bonusArmorPenPercent")
    bonus_magic_pen_percent: int = Field(..., alias="bonusMagicPenPercent")
    cc_reduction: int = Field(..., alias="ccReduction")
    cooldown_reduction: int = Field(..., alias="cooldownReduction")
    health: int
    health_max: int = Field(..., alias="healthMax")
    health_regen: int = Field(..., alias="healthRegen")
    lifesteal: int
    magic_pen: int = Field(..., alias="magicPen")
    magic_pen_percent: int = Field(..., alias="magicPenPercent")
    magic_resist: int = Field(..., alias="magicResist")
    movement_speed: int = Field(..., alias="movementSpeed")
    omnivamp: Optional[int] = None
    physical_vamp: Optional[int] = Field(None, alias="physicalVamp")
    power: int
    power_max: int = Field(..., alias="powerMax")
    power_regen: int = Field(..., alias="powerRegen")
    spell_vamp: int = Field(..., alias="spellVamp")


class DamageStatsDto(BaseModel):
    magic_damage_done: int = Field(..., alias="magicDamageDone")
    magic_damage_done_to_champions: int = Field(..., alias="magicDamageDoneToChampions")
    magic_damage_taken: int = Field(..., alias="magicDamageTaken")
    physical_damage_done: int = Field(..., alias="physicalDamageDone")
    physical_damage_done_to_champions: int = Field(
        ..., alias="physicalDamageDoneToChampions"
    )
    physical_damage_taken: int = Field(..., alias="physicalDamageTaken")
    total_damage_done: int = Field(..., alias="totalDamageDone")
    total_damage_done_to_champions: int = Field(..., alias="totalDamageDoneToChampions")
    total_damage_taken: int = Field(..., alias="totalDamageTaken")
    true_damage_done: int = Field(..., alias="trueDamageDone")
    true_damage_done_to_champions: int = Field(..., alias="trueDamageDoneToChampions")
    true_damage_taken: int = Field(..., alias="trueDamageTaken")


class PositionDto(BaseModel):
    x: int
    y: int


class MatchTimelineVictimDamage(BaseModel):
    basic: bool
    magic_damage: int = Field(..., alias="magicDamage")
    name: str
    participant_id: int = Field(..., alias="participantId")
    physical_damage: int = Field(..., alias="physicalDamage")
    spell_name: str = Field(..., alias="spellName")
    spell_slot: int = Field(..., alias="spellSlot")
    true_damage: int = Field(..., alias="trueDamage")
    type: str


class FeatDto(BaseModel):
    feat_state: Optional[int] = Field(None, alias="featState")


class PerkStyleDto(BaseModel):
    description: str
    selections: List[PerkStyleSelectionDto]
    style: int


class ObjectivesDto(BaseModel):
    baron: ObjectiveDto
    champion: ObjectiveDto
    dragon: ObjectiveDto
    horde: Optional[ObjectiveDto] = None
    inhibitor: ObjectiveDto
    rift_herald: ObjectiveDto = Field(..., alias="riftHerald")
    tower: ObjectiveDto
    atakhan: Optional[ObjectiveDto] = None


class EventsTimeLineDto(BaseModel):
    timestamp: int
    real_timestamp: Optional[int] = Field(None, alias="realTimestamp")
    type: str
    item_id: Optional[int] = Field(None, alias="itemId")
    participant_id: Optional[int] = Field(None, alias="participantId")
    level_up_type: Optional[str] = Field(None, alias="levelUpType")
    skill_slot: Optional[int] = Field(None, alias="skillSlot")
    creator_id: Optional[int] = Field(None, alias="creatorId")
    ward_type: Optional[str] = Field(None, alias="wardType")
    level: Optional[int] = None
    assisting_participant_ids: Optional[List[int]] = Field(
        None, alias="assistingParticipantIds"
    )
    bounty: Optional[int] = None
    kill_streak_length: Optional[int] = Field(None, alias="killStreakLength")
    killer_id: Optional[int] = Field(None, alias="killerId")
    position: Optional[PositionDto] = None
    victim_damage_dealt: Optional[List[MatchTimelineVictimDamage]] = Field(
        None, alias="victimDamageDealt"
    )
    victim_damage_received: Optional[List[MatchTimelineVictimDamage]] = Field(
        None, alias="victimDamageReceived"
    )
    victim_id: Optional[int] = Field(None, alias="victimId")
    kill_type: Optional[str] = Field(None, alias="killType")
    lane_type: Optional[str] = Field(None, alias="laneType")
    team_id: Optional[int] = Field(None, alias="teamId")
    multi_kill_length: Optional[int] = Field(None, alias="multiKillLength")
    killer_team_id: Optional[int] = Field(None, alias="killerTeamId")
    monster_type: Optional[str] = Field(None, alias="monsterType")
    monster_sub_type: Optional[str] = Field(None, alias="monsterSubType")
    building_type: Optional[str] = Field(None, alias="buildingType")
    tower_type: Optional[str] = Field(None, alias="towerType")
    after_id: Optional[int] = Field(None, alias="afterId")
    before_id: Optional[int] = Field(None, alias="beforeId")
    gold_gain: Optional[int] = Field(None, alias="goldGain")
    game_id: Optional[int] = Field(None, alias="gameId")
    winning_team: Optional[int] = Field(None, alias="winningTeam")
    transform_type: Optional[str] = Field(None, alias="transformType")
    name: Optional[str] = None
    shutdown_bounty: Optional[int] = Field(None, alias="shutdownBounty")
    actual_start_time: Optional[int] = Field(None, alias="actualStartTime")
    feat_type: Optional[int] = Field(None, alias="featType")
    feat_value: Optional[int] = Field(None, alias="featValue")


class ParticipantFrameDto(BaseModel):
    champion_stats: ChampionStatsDto = Field(..., alias="championStats")
    current_gold: int = Field(..., alias="currentGold")
    damage_stats: DamageStatsDto = Field(..., alias="damageStats")
    gold_per_second: int = Field(..., alias="goldPerSecond")
    jungle_minions_killed: int = Field(..., alias="jungleMinionsKilled")
    level: int
    minions_killed: int = Field(..., alias="minionsKilled")
    participant_id: int = Field(..., alias="participantId")
    position: PositionDto
    time_enemy_spent_controlled: int = Field(..., alias="timeEnemySpentControlled")
    total_gold: int = Field(..., alias="totalGold")
    xp: int


class FeatsDto(BaseModel):
    epic_monster_kill: Optional[FeatDto] = Field(None, alias="EPIC_MONSTER_KILL")
    first_blood: Optional[FeatDto] = Field(None, alias="FIRST_BLOOD")
    first_turret: Optional[FeatDto] = Field(None, alias="FIRST_TURRET")


class PerksDto(BaseModel):
    stat_perks: PerkStatsDto = Field(..., alias="statPerks")
    styles: List[PerkStyleDto]


class TeamDto(BaseModel):
    bans: List[BanDto]
    objectives: ObjectivesDto
    team_id: int = Field(..., alias="teamId")
    win: bool
    feats: Optional[FeatsDto] = None


class FramesTimeLineDto(BaseModel):
    events: List[EventsTimeLineDto]
    participant_frames: Optional[Dict[str, ParticipantFrameDto]] = Field(
        None, alias="participantFrames"
    )
    timestamp: int


class ParticipantFramesDto(BaseModel):
    field_1_9: ParticipantFrameDto = Field(
        ..., alias="1-9", description="Key value mapping for each participant"
    )


class ParticipantDto(BaseModel):
    all_in_pings: Optional[int] = Field(
        None, alias="allInPings", description="Yellow crossed swords"
    )
    assist_me_pings: Optional[int] = Field(
        None, alias="assistMePings", description="Green flag"
    )
    assists: int
    baron_kills: int = Field(..., alias="baronKills")
    bounty_level: Optional[int] = Field(None, alias="bountyLevel")
    champ_experience: int = Field(..., alias="champExperience")
    champ_level: int = Field(..., alias="champLevel")
    champion_id: int = Field(
        ...,
        alias="championId",
        description="Prior to patch 11.4, on Feb 18th, 2021, this field returned invalid championIds. We recommend determining the champion based on the championName field for matches played prior to patch 11.4.",
    )
    champion_name: str = Field(..., alias="championName")
    command_pings: Optional[int] = Field(
        None, alias="commandPings", description="Blue generic ping (ALT+click)"
    )
    champion_transform: int = Field(
        ...,
        alias="championTransform",
        description="This field is currently only utilized for Kayn's transformations. (Legal values: 0 - None, 1 - Slayer, 2 - Assassin)",
    )
    consumables_purchased: int = Field(..., alias="consumablesPurchased")
    challenges: Optional[ChallengesDto] = None
    damage_dealt_to_buildings: Optional[int] = Field(
        None, alias="damageDealtToBuildings"
    )
    damage_dealt_to_objectives: int = Field(..., alias="damageDealtToObjectives")
    damage_dealt_to_turrets: int = Field(..., alias="damageDealtToTurrets")
    damage_self_mitigated: int = Field(..., alias="damageSelfMitigated")
    deaths: int
    detector_wards_placed: int = Field(..., alias="detectorWardsPlaced")
    double_kills: int = Field(..., alias="doubleKills")
    dragon_kills: int = Field(..., alias="dragonKills")
    eligible_for_progression: Optional[bool] = Field(
        None, alias="eligibleForProgression"
    )
    enemy_missing_pings: Optional[int] = Field(
        None, alias="enemyMissingPings", description="Yellow questionmark"
    )
    enemy_vision_pings: Optional[int] = Field(
        None, alias="enemyVisionPings", description="Red eyeball"
    )
    first_blood_assist: bool = Field(..., alias="firstBloodAssist")
    first_blood_kill: bool = Field(..., alias="firstBloodKill")
    first_tower_assist: bool = Field(..., alias="firstTowerAssist")
    first_tower_kill: bool = Field(..., alias="firstTowerKill")
    game_ended_in_early_surrender: bool = Field(
        ...,
        alias="gameEndedInEarlySurrender",
        description="This is an offshoot of the OneStone challenge. The code checks if a spell with the same instance ID does the final point of damage to at least 2 Champions. It doesn't matter if they're enemies, but you cannot hurt your friends.",
    )
    game_ended_in_surrender: bool = Field(..., alias="gameEndedInSurrender")
    hold_pings: Optional[int] = Field(None, alias="holdPings")
    get_back_pings: Optional[int] = Field(
        None, alias="getBackPings", description="Yellow circle with horizontal line"
    )
    gold_earned: int = Field(..., alias="goldEarned")
    gold_spent: int = Field(..., alias="goldSpent")
    individual_position: str = Field(
        ...,
        alias="individualPosition",
        description="Both individualPosition and teamPosition are computed by the game server and are different versions of the most likely position played by a player. The individualPosition is the best guess for which position the player actually played in isolation of anything else. The teamPosition is the best guess for which position the player actually played if we add the constraint that each team must have one top player, one jungle, one middle, etc. Generally the recommendation is to use the teamPosition field over the individualPosition field.",
    )
    inhibitor_kills: int = Field(..., alias="inhibitorKills")
    inhibitor_takedowns: Optional[int] = Field(None, alias="inhibitorTakedowns")
    inhibitors_lost: Optional[int] = Field(None, alias="inhibitorsLost")
    item0: int
    item1: int
    item2: int
    item3: int
    item4: int
    item5: int
    item6: int
    items_purchased: int = Field(..., alias="itemsPurchased")
    killing_sprees: int = Field(..., alias="killingSprees")
    kills: int
    lane: str
    largest_critical_strike: int = Field(..., alias="largestCriticalStrike")
    largest_killing_spree: int = Field(..., alias="largestKillingSpree")
    largest_multi_kill: int = Field(..., alias="largestMultiKill")
    longest_time_spent_living: int = Field(..., alias="longestTimeSpentLiving")
    magic_damage_dealt: int = Field(..., alias="magicDamageDealt")
    magic_damage_dealt_to_champions: int = Field(
        ..., alias="magicDamageDealtToChampions"
    )
    magic_damage_taken: int = Field(..., alias="magicDamageTaken")
    missions: Optional[MissionsDto] = None
    neutral_minions_killed: int = Field(
        ...,
        alias="neutralMinionsKilled",
        description="neutralMinionsKilled = mNeutralMinionsKilled, which is incremented on kills of kPet and kJungleMonster",
    )
    need_vision_pings: Optional[int] = Field(
        None, alias="needVisionPings", description="Green ward"
    )
    nexus_kills: int = Field(..., alias="nexusKills")
    nexus_takedowns: Optional[int] = Field(None, alias="nexusTakedowns")
    nexus_lost: Optional[int] = Field(None, alias="nexusLost")
    objectives_stolen: int = Field(..., alias="objectivesStolen")
    objectives_stolen_assists: int = Field(..., alias="objectivesStolenAssists")
    on_my_way_pings: Optional[int] = Field(
        None, alias="onMyWayPings", description="Blue arrow pointing at ground"
    )
    participant_id: int = Field(..., alias="participantId")
    player_score0: Optional[float] = Field(None, alias="playerScore0")
    player_score1: Optional[float] = Field(None, alias="playerScore1")
    player_score2: Optional[float] = Field(None, alias="playerScore2")
    player_score3: Optional[float] = Field(None, alias="playerScore3")
    player_score4: Optional[float] = Field(None, alias="playerScore4")
    player_score5: Optional[float] = Field(None, alias="playerScore5")
    player_score6: Optional[float] = Field(None, alias="playerScore6")
    player_score7: Optional[float] = Field(None, alias="playerScore7")
    player_score8: Optional[float] = Field(None, alias="playerScore8")
    player_score9: Optional[float] = Field(None, alias="playerScore9")
    player_score10: Optional[float] = Field(None, alias="playerScore10")
    player_score11: Optional[float] = Field(None, alias="playerScore11")
    penta_kills: int = Field(..., alias="pentaKills")
    perks: PerksDto
    physical_damage_dealt: int = Field(..., alias="physicalDamageDealt")
    physical_damage_dealt_to_champions: int = Field(
        ..., alias="physicalDamageDealtToChampions"
    )
    physical_damage_taken: int = Field(..., alias="physicalDamageTaken")
    placement: Optional[int] = None
    player_augment1: Optional[int] = Field(None, alias="playerAugment1")
    player_augment2: Optional[int] = Field(None, alias="playerAugment2")
    player_augment3: Optional[int] = Field(None, alias="playerAugment3")
    player_augment4: Optional[int] = Field(None, alias="playerAugment4")
    player_subteam_id: Optional[int] = Field(None, alias="playerSubteamId")
    push_pings: Optional[int] = Field(
        None, alias="pushPings", description="Green minion"
    )
    profile_icon: int = Field(..., alias="profileIcon")
    puuid: str
    quadra_kills: int = Field(..., alias="quadraKills")
    riot_id_game_name: Optional[str] = Field(None, alias="riotIdGameName")
    riot_id_tagline: Optional[str] = Field(None, alias="riotIdTagline")
    role: str
    sight_wards_bought_in_game: int = Field(..., alias="sightWardsBoughtInGame")
    spell1_casts: int = Field(..., alias="spell1Casts")
    spell2_casts: int = Field(..., alias="spell2Casts")
    spell3_casts: int = Field(..., alias="spell3Casts")
    spell4_casts: int = Field(..., alias="spell4Casts")
    subteam_placement: Optional[int] = Field(None, alias="subteamPlacement")
    summoner1_casts: int = Field(..., alias="summoner1Casts")
    summoner1_id: int = Field(..., alias="summoner1Id")
    summoner2_casts: int = Field(..., alias="summoner2Casts")
    summoner2_id: int = Field(..., alias="summoner2Id")
    summoner_id: str = Field(..., alias="summonerId")
    summoner_level: int = Field(..., alias="summonerLevel")
    summoner_name: str = Field(..., alias="summonerName")
    team_early_surrendered: bool = Field(..., alias="teamEarlySurrendered")
    team_id: int = Field(..., alias="teamId")
    team_position: str = Field(
        ...,
        alias="teamPosition",
        description="Both individualPosition and teamPosition are computed by the game server and are different versions of the most likely position played by a player. The individualPosition is the best guess for which position the player actually played in isolation of anything else. The teamPosition is the best guess for which position the player actually played if we add the constraint that each team must have one top player, one jungle, one middle, etc. Generally the recommendation is to use the teamPosition field over the individualPosition field.",
    )
    time_c_cing_others: int = Field(..., alias="timeCCingOthers")
    time_played: int = Field(..., alias="timePlayed")
    total_ally_jungle_minions_killed: Optional[int] = Field(
        None, alias="totalAllyJungleMinionsKilled"
    )
    total_damage_dealt: int = Field(..., alias="totalDamageDealt")
    total_damage_dealt_to_champions: int = Field(
        ..., alias="totalDamageDealtToChampions"
    )
    total_damage_shielded_on_teammates: int = Field(
        ..., alias="totalDamageShieldedOnTeammates"
    )
    total_damage_taken: int = Field(..., alias="totalDamageTaken")
    total_enemy_jungle_minions_killed: Optional[int] = Field(
        None, alias="totalEnemyJungleMinionsKilled"
    )
    total_heal: int = Field(
        ...,
        alias="totalHeal",
        description="Whenever positive health is applied (which translates to all heals in the game but not things like regeneration), totalHeal is incremented by the amount of health received. This includes healing enemies, jungle monsters, yourself, etc",
    )
    total_heals_on_teammates: int = Field(
        ...,
        alias="totalHealsOnTeammates",
        description="Whenever positive health is applied (which translates to all heals in the game but not things like regeneration), totalHealsOnTeammates is incremented by the amount of health received.  This is post modified, so if you heal someone missing 5 health for 100 you will get +5 totalHealsOnTeammates",
    )
    total_minions_killed: int = Field(
        ...,
        alias="totalMinionsKilled",
        description="totalMillionsKilled = mMinionsKilled, which is only incremented on kills of kTeamMinion, kMeleeLaneMinion, kSuperLaneMinion, kRangedLaneMinion and kSiegeLaneMinion",
    )
    total_time_cc_dealt: int = Field(..., alias="totalTimeCCDealt")
    total_time_spent_dead: int = Field(..., alias="totalTimeSpentDead")
    total_units_healed: int = Field(..., alias="totalUnitsHealed")
    triple_kills: int = Field(..., alias="tripleKills")
    true_damage_dealt: int = Field(..., alias="trueDamageDealt")
    true_damage_dealt_to_champions: int = Field(..., alias="trueDamageDealtToChampions")
    true_damage_taken: int = Field(..., alias="trueDamageTaken")
    turret_kills: int = Field(..., alias="turretKills")
    turret_takedowns: Optional[int] = Field(None, alias="turretTakedowns")
    turrets_lost: Optional[int] = Field(None, alias="turretsLost")
    unreal_kills: int = Field(..., alias="unrealKills")
    vision_score: int = Field(..., alias="visionScore")
    vision_cleared_pings: Optional[int] = Field(None, alias="visionClearedPings")
    vision_wards_bought_in_game: int = Field(..., alias="visionWardsBoughtInGame")
    wards_killed: int = Field(..., alias="wardsKilled")
    wards_placed: int = Field(..., alias="wardsPlaced")
    win: bool
    bait_pings: Optional[int] = Field(None, alias="baitPings")
    danger_pings: Optional[int] = Field(
        None,
        alias="dangerPings",
        description="https://github.com/RiotGames/developer-relations/issues/870",
    )
    basic_pings: Optional[int] = Field(
        None,
        alias="basicPings",
        description="https://github.com/RiotGames/developer-relations/issues/814",
    )
    player_augment5: Optional[int] = Field(None, alias="playerAugment5")
    player_augment6: Optional[int] = Field(None, alias="playerAugment6")
    riot_id_name: Optional[str] = Field(
        None,
        alias="riotIdName",
        description="Deprecated, use `riotIdGameName`. This field name was briefly used instead of `riotIdGameName`, prior to patch 14.5.",
    )
    retreat_pings: Optional[int] = Field(
        None,
        alias="retreatPings",
        description="https://github.com/RiotGames/developer-relations/issues/814",
    )
    champion_skin_id: Optional[int] = Field(None, alias="championSkinId")


class InfoTimeLineDto(BaseModel):
    end_of_game_result: Optional[str] = Field(
        None,
        alias="endOfGameResult",
        description="Refer to indicate if the game ended in termination.",
    )
    frame_interval: int = Field(..., alias="frameInterval")
    game_id: Optional[int] = Field(None, alias="gameId")
    participants: Optional[List[ParticipantTimeLineDto]] = None
    frames: List[FramesTimeLineDto]


class InfoDto(BaseModel):
    end_of_game_result: Optional[str] = Field(
        None,
        alias="endOfGameResult",
        description="Refer to indicate if the game ended in termination.",
    )
    game_creation: int = Field(
        ...,
        alias="gameCreation",
        description="Unix timestamp for when the game is created on the game server (i.e., the loading screen).",
    )
    game_duration: int = Field(
        ...,
        alias="gameDuration",
        description="Prior to patch 11.20, this field returns the game length in milliseconds calculated from gameEndTimestamp - gameStartTimestamp. Post patch 11.20, this field returns the max timePlayed of any participant in the game in seconds, which makes the behavior of this field consistent with that of match-v4. The best way to handling the change in this field is to treat the value as milliseconds if the gameEndTimestamp field isn't in the response and to treat the value as seconds if gameEndTimestamp is in the response.",
    )
    game_end_timestamp: Optional[int] = Field(
        None,
        alias="gameEndTimestamp",
        description='Unix timestamp for when match ends on the game server. This timestamp can occasionally be significantly longer than when the match "ends". The most reliable way of determining the timestamp for the end of the match would be to add the max time played of any participant to the gameStartTimestamp. This field was added to match-v5 in patch 11.20 on Oct 5th, 2021.',
    )
    game_id: int = Field(..., alias="gameId")
    game_mode: str = Field(
        ..., alias="gameMode", description="Refer to the Game Constants documentation."
    )
    game_name: str = Field(..., alias="gameName")
    game_start_timestamp: int = Field(
        ...,
        alias="gameStartTimestamp",
        description="Unix timestamp for when match starts on the game server.",
    )
    game_type: str = Field(..., alias="gameType")
    game_version: str = Field(
        ...,
        alias="gameVersion",
        description="The first two parts can be used to determine the patch a game was played on.",
    )
    map_id: int = Field(
        ..., alias="mapId", description="Refer to the Game Constants documentation."
    )
    participants: List[ParticipantDto]
    platform_id: str = Field(
        ..., alias="platformId", description="Platform where the match was played."
    )
    queue_id: int = Field(
        ..., alias="queueId", description="Refer to the Game Constants documentation."
    )
    teams: List[TeamDto]
    tournament_code: Optional[str] = Field(
        None,
        alias="tournamentCode",
        description="Tournament code used to generate the match. This field was added to match-v5 in patch 11.13 on June 23rd, 2021.",
    )
    game_mode_mutators: Optional[List[str]] = Field(None, alias="gameModeMutators")


class TimelineDto(BaseModel):
    metadata: MetadataTimeLineDto = Field(..., description="Match metadata.")
    info: InfoTimeLineDto = Field(..., description="Match info.")


class MatchDto(BaseModel):
    metadata: MetadataDto = Field(..., description="Match metadata.")
    info: InfoDto = Field(..., description="Match info.")



from pyke import Region

from .._base_client import _BaseApiClient
from .._models.status_v4 import PlatformDataDto


class StatusEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def platform_data(self, region: Region) -> PlatformDataDto:
        """# Get League of Legends status for the given platform

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  

        **Returns:**  
            `PlatformDataDto:` pyke._models.status_v4.PlatformDataDto
        """  # fmt: skip

        path = "/lol/status/v4/platform-data"
        data = self._client._region_request(region=region, path=path)

        return PlatformDataDto(**data)



# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Field


class Position(Enum):
    unselected = "UNSELECTED"
    fill = "FILL"
    top = "TOP"
    jungle = "JUNGLE"
    middle = "MIDDLE"
    bottom = "BOTTOM"
    utility = "UTILITY"


class Role(Enum):
    captain = "CAPTAIN"
    member = "MEMBER"


class PlayerDto(BaseModel):
    puuid: str
    team_id: Optional[str] = Field(None, alias="teamId")
    position: Position = Field(
        ...,
        description="(Legal values:  UNSELECTED,  FILL,  TOP,  JUNGLE,  MIDDLE,  BOTTOM,  UTILITY)",
    )
    role: Role = Field(..., description="(Legal values:  CAPTAIN,  MEMBER)")


class TeamDto(BaseModel):
    id: str
    tournament_id: int = Field(..., alias="tournamentId")
    name: str
    icon_id: int = Field(..., alias="iconId")
    tier: int
    captain: str = Field(..., description="Summoner ID of the team captain.")
    abbreviation: str
    players: List[PlayerDto] = Field(..., description="Team members.")


class TournamentPhaseDto(BaseModel):
    id: int
    registration_time: int = Field(..., alias="registrationTime")
    start_time: int = Field(..., alias="startTime")
    cancelled: bool


class TournamentDto(BaseModel):
    id: int
    theme_id: int = Field(..., alias="themeId")
    name_key: str = Field(..., alias="nameKey")
    name_key_secondary: str = Field(..., alias="nameKeySecondary")
    schedule: List[TournamentPhaseDto] = Field(..., description="Tournament phase.")



from pyke import Division, Queue, Region, Tier

from .._base_client import _BaseApiClient
from .._models.league_v4 import LeagueEntryDTO, LeagueListDTO


class LeagueEndpoint:
    def __init__(self, client: _BaseApiClient):
        self._client = client

    def challenger_leagues_by_queue(
        self,
        region: Region,
        queue: Queue,
    ) -> LeagueListDTO:
        """# Get the challenger league for given queue

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `queue (Queue):` Ranked queue type (pyke._enums.queue.Queue).  

        **Returns:**  
            `LeagueListDTO:` pyke._models.league_v4.LeagueListDTO object.
        """  # fmt: skip

        path = f"/lol/league/v4/challengerleagues/by-queue/{queue.value}"
        data = self._client._region_request(region=region, path=path)

        return LeagueListDTO(**data)

    def by_puuid(self, region: Region, puuid: str) -> list[LeagueEntryDTO]:
        """# Get league entries in all queues for a given puuid

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `puuid (str):` Encrypted PUUID. Exact length of 78 characters.  

        **Returns:**  
            `list[LeagueEntryDTO]:` List of pyke._models.league_exp_v4.LeagueEntryDTO objects.
        """  # fmt: skip

        path = f"/lol/league/v4/entries/by-puuid/{puuid}"
        data = self._client._region_request(region=region, path=path)

        league_entries: list[LeagueEntryDTO] = []

        for league_entry in data:
            league_entries.append(LeagueEntryDTO(**league_entry))

        return league_entries

    def by_queue_tier_division(
        self,
        region: Region,
        queue: Queue,
        tier: Tier,
        division: Division,
        page: int = 1,
    ) -> list[LeagueEntryDTO]:
        """# Get all the league entries

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `queue (Queue):` Ranked queue type (pyke._enums.queue.Queue).  
            `tier (Tier):` Ranked tier (pyke._enums.tier.Tier).  
            `division (Division):` Ranked division (pyke._enums.division.Division).  
            `page (int, optional):` Starts with page 1. Defaults to 1.  

        **Returns:**  
            `list[LeagueEntryDTO]:` List of pyke._models.league_v4.LeagueEntryDTO objects.
        """  # fmt: skip

        path = f"/lol/league/v4/entries/{queue.value}/{tier.value}/{division.value}"
        params = {"count": page}
        data = self._client._region_request(region=region, path=path, params=params)

        league_entries: list[LeagueEntryDTO] = []

        for league_entry in data:
            league_entries.append(LeagueEntryDTO(**league_entry))

        return league_entries

    def grandmaster_leagues_by_queue(
        self,
        region: Region,
        queue: Queue,
    ) -> LeagueListDTO:
        """# Get the grandmaster league for given queue

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `queue (Queue):` Ranked queue type (pyke._enums.queue.Queue).  

        **Returns:**  
            `LeagueListDTO:` pyke._models.league_v4.LeagueListDTO object.  
        """  # fmt: skip

        path = f"/lol/league/v4/grandmasterleagues/by-queue/{queue.value}"
        data = self._client._region_request(region=region, path=path)

        return LeagueListDTO(**data)

    def by_league_id(self, region: Region, league_id: str) -> LeagueListDTO:
        """# Get league with given ID, including inactive entries

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `league_id (str):` League id.  

        **Returns:**  
            `LeagueListDTO:` pyke._models.league_v4.LeagueListDTO object.
        """  # fmt: skip

        path = f"/lol/league/v4/leagues/{league_id}"
        data = self._client._region_request(region=region, path=path)

        return LeagueListDTO(**data)

    def master_leagues_by_queue(
        self,
        region: Region,
        queue: Queue,
    ) -> LeagueListDTO:
        """# Get the master league for given queue

        **Args:**  
            `region (Region):` Region to execute against (pyke._enums.region.Region).  
            `queue (Queue):` Ranked queue type (pyke._enums.queue.Queue).  

        **Returns:**  
            `LeagueListDTO:` pyke._models.league_v4.LeagueListDTO object.
        """  # fmt: skip

        path = f"/lol/league/v4/masterleagues/by-queue/{queue.value}"
        data = self._client._region_request(region=region, path=path)

        return LeagueListDTO(**data)
